This is the homepage of our GKQUIZ project..

This project is build on the basis of Knowledge purposes. 

This is a GK quiz mini project that test your knowldege via 'OBJECTIVE MCQ'.

In this project include 4 different GK MODULES namely.

SCIENCE QUIZ

HITORY QUIZ

GEOGRAPHY AND

GENERAL AWARENESS..

Through this project you enhance your knowledge skills and also test your IQ level.

We have create 'GRADE' SYSTEM in this project, so you can check your GRADE according to your performance.

We have also include 'NEGATIVE MARKING' CONCEPT in this.

Note: You have to type exact option that mentioned in the option scheme e.g.

Q.) which is the capital of India ?

a) Delhi

b) Chandigarh

c) Mumbai

d) Kolkata

Type your answer here : <Delhi>  

--You have to type exact option like typed in this example  

I hope you would like and enjoy it, Please appreciate of our work.

Thanks and regards

Ash bhatia Team

for more information and queries, please contact us below mention mails:

EMAILID: ashbhatia2@gmail.com, ashbhatia20@gmail.com
